<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Banned!</title>
</head>
<body>
<style>
    .box{
        margin-top: 200px;
        color:red;
    }
</style>

<center>
<h1 class="box">You are permanently banned by admin</h1>
    <hr>
<b><mark>Rule violation</mark></b>
</center>

</body>
</html>